# Copyright 2014, Abiquo
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'spec_helper'
require_relative 'support/stubs'

describe 'abiquo::install_frontend' do
  before do
    stub_certificate_files('/etc/pki/abiquo/fauxhai.local.crt', '/etc/pki/abiquo/fauxhai.local.key')
    stub_command('/usr/sbin/httpd -t').and_return(true)
    stub_command('/usr/bin/test -f /etc/pki/abiquo/fauxhai.local.crt').and_return(false)
  end

  cached(:chef_run) do
    ChefSpec::SoloRunner.new do |node|
      node.normal['abiquo']['certificate']['common_name'] = 'fauxhai.local'
    end.converge('apache2::default', described_recipe, 'abiquo::setup_frontend', 'abiquo::service')
  end

  it 'installs the Apache recipes' do
    expect(chef_run).to include_recipe('apache2')
    expect(chef_run).to include_recipe('apache2::mod_proxy_ajp')
    expect(chef_run).to include_recipe('apache2::mod_ssl')
  end

  %w(ui tutorials).each do |pkg|
    it "installs the abiquo-#{pkg} abiquo package" do
      expect(chef_run).to install_package("abiquo-#{pkg}")
    end
  end

  it 'includes the certificate recipe' do
    expect(chef_run).to include_recipe('abiquo::certificate')
  end

  # The apache webapp calls can't be tested because it is not a LWRP
  # but a definition and does not exist in the resource list
end
